#
# Copyright (c) 2008-2018 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

from persistent import Persistent
from zope.interface import Interface
from zope.location import Location
from zope.schema.fieldproperty import FieldProperty

from onf_website.shared.common.skin.interfaces import IHubHeaderWithImagesPortletRendererSettings
from onf_website.skin.public import jquery_tilt
from onf_website.skin.public.layer import IONFBaseLayer
from pyams_content.shared.common.portlet.interfaces import ISharedContentHeaderPortletSettings
from pyams_default_theme.interfaces import IContentBannerIllustration
from pyams_default_theme.shared.common.portlet.head import SharedContentHeaderPortletRenderer
from pyams_file.property import FileProperty
from pyams_i18n.interfaces import II18n
from pyams_portal.interfaces import IPortalContext, IPortletRenderer
from pyams_skin.layer import IPyAMSLayer
from pyams_template.template import template_config
from pyams_utils.adapter import adapter_config
from pyams_utils.factory import factory_config


__docformat__ = 'restructuredtext'

from onf_website import _


@adapter_config(context=(IPortalContext, IPyAMSLayer, Interface,
                         ISharedContentHeaderPortletSettings),
                provides=IPortletRenderer)
@template_config(template='templates/head.pt', layer=IONFBaseLayer)
class BaseHeaderPortletRenderer(SharedContentHeaderPortletRenderer):
    """Base header portlet renderer"""

    label = _("ONF: Standard header with banner (default)")
    illustration_interface = IContentBannerIllustration

    @property
    def illustration(self):
        if not self.settings.display_illustration:
            return None, None, None
        registry = self.request.registry
        illustration = registry.queryMultiAdapter((self.context, self.request),
                                                  self.illustration_interface)
        if (illustration is None) or not illustration.has_data():
            return None, None, None
        data = II18n(illustration).query_attribute('data', request=self.request)
        if data.content_type.startswith('video'):
            return illustration, data, 'video'
        return illustration, data, 'illustration'


#
# Site root head portlet renderer
#

@adapter_config(name='ONF::head-root',
                context=(IPortalContext, IPyAMSLayer, Interface,
                         ISharedContentHeaderPortletSettings),
                provides=IPortletRenderer)
@template_config(template='templates/head-root.pt', layer=IONFBaseLayer)
class RootHeaderPortletRenderer(BaseHeaderPortletRenderer):
    """Root header portlet renderer"""

    label = _("ONF: Site root header with panoramic illustrations")
    weight = 10


#
# News-like head portlet renderer
#

@adapter_config(name='ONF::head-news',
                context=(IPortalContext, IPyAMSLayer, Interface,
                         ISharedContentHeaderPortletSettings),
                provides=IPortletRenderer)
@template_config(template='templates/head-news.pt', layer=IONFBaseLayer)
class NewsHeaderPortletRenderer(BaseHeaderPortletRenderer):
    """News header portlet renderer"""

    label = _("ONF: News header with panoramic illustrations")
    weight = 20


#
# Hub header portlet renderer
#

@adapter_config(name='ONF::head-hub',
                context=(IPortalContext, IPyAMSLayer, Interface,
                         ISharedContentHeaderPortletSettings),
                provides=IPortletRenderer)
@template_config(template='templates/head-hub.pt', layer=IONFBaseLayer)
class HubHeaderPortletRenderer(BaseHeaderPortletRenderer):
    """Hub header portlet renderer"""

    label = _("ONF: Hub header with text or banner")
    weight = 30


#
# Hub header with custom images portlet renderer
#

@factory_config(provided=IHubHeaderWithImagesPortletRendererSettings)
class HubHeaderWithImagesPortletRendererSettings(Persistent, Location):
    """Hub header portlet with images renderer settings"""

    background_image = FileProperty(
        IHubHeaderWithImagesPortletRendererSettings['background_image'])
    foreground_left_image = FileProperty(
        IHubHeaderWithImagesPortletRendererSettings['foreground_left_image'])
    foreground_right_image = FileProperty(
        IHubHeaderWithImagesPortletRendererSettings['foreground_right_image'])
    heading = FieldProperty(
        IHubHeaderWithImagesPortletRendererSettings['heading'])


@adapter_config(name='ONF::head-hub-images',
                context=(IPortalContext, IPyAMSLayer, Interface,
                         ISharedContentHeaderPortletSettings),
                provides=IPortletRenderer)
@template_config(template='templates/head-hub-images.pt', layer=IONFBaseLayer)
class HubHeaderWithImagesPortletRenderer(BaseHeaderPortletRenderer):
    """Hub header portlet renderer with """

    label = _("ONF: Hub header with text and custom images")
    weight = 40

    settings_interface = IHubHeaderWithImagesPortletRendererSettings


#
# Forest header portlet renderer
#

@adapter_config(name='ONF::head-forest',
                context=(IPortalContext, IPyAMSLayer, Interface,
                         ISharedContentHeaderPortletSettings),
                provides=IPortletRenderer)
@template_config(template='templates/head-forest.pt', layer=IONFBaseLayer)
class ForestHeaderPortletRenderer(BaseHeaderPortletRenderer):
    """Forest header portlet renderer"""

    label = _("ONF: Forest header with illustration")
    weight = 50

    resources = (jquery_tilt, )